@@ -39,7 +39,7 @@
 #  include <config.h>
 #endif
 
-#include <sys/poll.h>
+#include <poll.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <unistd.h>
