@@ -49,7 +49,7 @@
 #include <strings.h>
 #include <unistd.h>
 #include <signal.h>
-#include <sys/poll.h>
+#include <poll.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <sys/param.h>		/* MAXPATHLEN */
