@@ -443,7 +443,7 @@ static int _cluster_get_jobs(mysql_conn_t *mysql_conn,
 			xstrcat(extra, ")");
 		else {
 			xfree(extra);
-			debug("User %s has no assocations, and is not admin, "
+			debug("User %s has no associations, and is not admin, "
 			      "so not returning any jobs.", user->name);
 			/* This user has no valid associations, so
 			 * they will not have any jobs. */
@@ -1543,7 +1543,7 @@ extern List as_mysql_jobacct_process_get_jobs(mysql_conn_t *mysql_conn,
 			is_user_any_coord(mysql_conn, &user);
 		}
 		if (!is_admin && !user.name) {
-			debug("User %u has no assocations, and is not admin, "
+			debug("User %u has no associations, and is not admin, "
 			      "so not returning any jobs.", user.uid);
 			return NULL;
 		}
