@@ -1177,7 +1177,7 @@ extern List as_mysql_get_users(mysql_conn_t *mysql_conn, uid_t uid,
 				mysql_conn, &user, 1, NULL);
 		}
 		if (!is_admin && !user.name) {
-			debug("User %u has no assocations, and is not admin, "
+			debug("User %u has no associations, and is not admin, "
 			      "so not returning any users.", user.uid);
 			return NULL;
 		}
