@@ -70,9 +70,9 @@
 struct part_row_data {
 	bitstr_t *row_bitmap;		/* contains core bitmap for all jobs in
 					 * this row */
-	uint32_t num_jobs;		/* Number of jobs in this row */
 	struct job_resources **job_list;/* List of jobs in this row */
 	uint32_t job_list_size;		/* Size of job_list array */
+	uint32_t num_jobs;		/* Number of occupied entries in job_list array */
 };
 
 /* partition CPU allocation data */
