@@ -64,15 +64,17 @@
 #include "src/common/list.h"
 #include "src/common/log.h"
 #include "src/common/read_config.h"
+#include "src/common/slurm_protocol_api.h"
 #include "src/common/slurm_protocol_defs.h"
+#include "src/common/timers.h"
 #include "src/common/xstring.h"
 #include "src/common/xmalloc.h"
 #include "src/scancel/scancel.h"
 
 #define MAX_CANCEL_RETRY 10
-#define MAX_THREADS 2
-
+#define MAX_THREADS 10
 
+static void  _add_delay(void);
 static int   _cancel_jobs (int filter_cnt);
 static void *_cancel_job_id (void *cancel_info);
 static void *_cancel_step_id (void *cancel_info);
@@ -106,6 +108,9 @@ static	pthread_attr_t  attr;
 static	int num_active_threads = 0;
 static	pthread_mutex_t  num_active_threads_lock;
 static	pthread_cond_t   num_active_threads_cond;
+static	pthread_mutex_t  max_delay_lock;
+static	uint32_t max_resp_time = 0;
+static	int request_count = 0;
 
 int
 main (int argc, char *argv[])
@@ -650,6 +655,41 @@ static int _cancel_jobs(int filter_cnt)
 	return rc;
 }
 
+/* scancel can cancel huge numbers of job from a single command line using
+ * pthreads for parallelism. Add a delay if there are many RPCs and response
+ * delays get excessive to avoid causing a denial of service attack. */
+static void _add_delay(void)
+{
+	static int target_resp_time = -1;
+	static int delay_time = 10000, previous_delay = 0;
+	int my_delay;
+
+	pthread_mutex_lock(&max_delay_lock);
+	if (target_resp_time < 0) {
+		target_resp_time = slurm_get_msg_timeout() / 4;
+		target_resp_time = MAX(target_resp_time, 3);
+		target_resp_time = MIN(target_resp_time, 5);
+		target_resp_time *= 1000000;
+		debug("%s: target response time = %d", __func__,
+		      target_resp_time);
+	}
+	if ((++request_count < MAX_THREADS) ||
+	    (max_resp_time <= target_resp_time)) {
+		pthread_mutex_unlock(&max_delay_lock);
+		return;
+	}
+
+	/* Maximum delay of 1 second. Start at 10 msec with Fibonacci backoff */
+	my_delay = MIN((delay_time + previous_delay), 1000000);
+	previous_delay = delay_time;
+	delay_time = my_delay;
+	pthread_mutex_unlock(&max_delay_lock);
+
+	info("%s: adding delay in RPC send of %d usec", __func__, my_delay);
+	usleep(my_delay);
+	return;
+}
+
 static void *
 _cancel_job_id (void *ci)
 {
@@ -658,6 +698,7 @@ _cancel_job_id (void *ci)
 	bool sig_set = true;
 	uint16_t flags = 0;
 	char *job_type = "";
+	DEF_TIMERS;
 
 	if (cancel_info->sig == (uint16_t) NO_VAL) {
 		cancel_info->sig = SIGKILL;
@@ -698,8 +739,15 @@ _cancel_job_id (void *ci)
 	}
 
 	for (i = 0; i < MAX_CANCEL_RETRY; i++) {
+		_add_delay();
+		START_TIMER;
 		error_code = slurm_kill_job2(cancel_info->job_id_str,
 					     cancel_info->sig, flags);
+		END_TIMER;
+		pthread_mutex_lock(&max_delay_lock);
+		max_resp_time = MAX(max_resp_time, DELTA_TIMER);
+		pthread_mutex_unlock(&max_delay_lock);
+
 		if ((error_code == 0) ||
 		    (errno != ESLURM_TRANSITION_STATE_NO_UPDATE))
 			break;
@@ -744,6 +792,7 @@ _cancel_step_id (void *ci)
 	uint32_t job_id  = cancel_info->job_id;
 	uint32_t step_id = cancel_info->step_id;
 	bool sig_set = true;
+	DEF_TIMERS;
 
 	if (cancel_info->sig == (uint16_t) NO_VAL) {
 		cancel_info->sig = SIGKILL;
@@ -775,6 +824,8 @@ _cancel_step_id (void *ci)
 				cancel_info->job_id_str, step_id);
 		}
 
+		_add_delay();
+		START_TIMER;
 		if ((!sig_set) || opt.ctld)
 			error_code = slurm_kill_job_step(job_id, step_id,
 							 cancel_info->sig);
@@ -783,6 +834,11 @@ _cancel_step_id (void *ci)
 		else
 			error_code = slurm_signal_job_step(job_id, step_id,
 							   cancel_info->sig);
+		END_TIMER;
+		pthread_mutex_lock(&max_delay_lock);
+		max_resp_time = MAX(max_resp_time, DELTA_TIMER);
+		pthread_mutex_unlock(&max_delay_lock);
+
 		if ((error_code == 0) ||
 		    ((errno != ESLURM_TRANSITION_STATE_NO_UPDATE) &&
 		     (errno != ESLURM_JOB_PENDING)))
