@@ -664,7 +664,7 @@ int main(int argc, char *argv[])
 
 	/* Purge our local data structures */
 	job_fini();
-	part_fini();	/* part_fini() must preceed node_fini() */
+	part_fini();	/* part_fini() must precede node_fini() */
 	node_fini();
 	purge_front_end_state();
 	resv_fini();
@@ -2103,6 +2103,7 @@ extern void set_cluster_tres(bool assoc_mgr_locked)
 	struct node_record *node_ptr;
 	slurmdb_tres_rec_t *tres_rec, *cpu_tres = NULL, *mem_tres = NULL;
 	int i;
+	char *unique_tres = NULL;
 	assoc_mgr_lock_t locks = { NO_LOCK, NO_LOCK, NO_LOCK, NO_LOCK,
 				   WRITE_LOCK, NO_LOCK, NO_LOCK };
 
@@ -2120,6 +2121,14 @@ extern void set_cluster_tres(bool assoc_mgr_locked)
 			      tres_rec->id);
 			continue; /* this should never happen */
 		}
+
+		if (unique_tres)
+			xstrfmtcat(unique_tres, ",%s",
+				   assoc_mgr_tres_name_array[i]);
+		else
+			unique_tres = xstrdup(assoc_mgr_tres_name_array[i]);
+
+
 		/* reset them now since we are about to add to them */
 		tres_rec->count = 0;
 		if (tres_rec->id == TRES_CPU) {
@@ -2142,6 +2151,9 @@ extern void set_cluster_tres(bool assoc_mgr_locked)
 		/* FIXME: set up the other tres here that aren't specific */
 	}
 
+	slurm_set_accounting_storage_tres(unique_tres);
+	xfree(unique_tres);
+
 	cluster_cpus = 0;
 
 	node_ptr = node_record_table_ptr;
@@ -2542,6 +2554,7 @@ static void _verify_clustername(void)
 	if ((fp = fopen(filename, "r"))) {
 		/* read value and compare */
 		fgets(name, sizeof(name), fp);
+		fclose(fp);
 		if (xstrcmp(name, slurmctld_conf.cluster_name)) {
 			fatal("CLUSTER NAME MISMATCH.\n"
 				"slurmctld has been started with \""
@@ -2568,10 +2581,10 @@ static void _verify_clustername(void)
 				__FUNCTION__, filename);
 			exit(1);
 		}
+		fclose(fp);
 	}
 
 	xfree(filename);
-	fclose(fp);
 }
 
 /* Kill the currently running slurmctld
