@@ -43,7 +43,7 @@
 #include <arpa/inet.h>
 #include <pthread.h>
 #include <signal.h>
-#include <sys/poll.h>
+#include <poll.h>
 #include <sys/time.h>
 #include <sys/types.h>
 #include <sys/socket.h>
